@@ -3,11 +3,12 @@
 #include <QSettings>
 #include <QPushButton>
 #include <QMessageBox>
+#include <QFont>
 
 #include "advsettingsdlg.h"
 #include "settingstable.h"
 
-AdvSettingsDlg::AdvSettingsDlg(QDialog *parent)
+AdvSettingsDlg::AdvSettingsDlg(QWidget *parent)
     : QDialog(parent)
     , layout(NULL)
     , btnLayout(NULL)
@@ -39,6 +40,10 @@ AdvSettingsDlg::AdvSettingsDlg(QDialog *parent)
     layout->addWidget(table, Qt::AlignLeft);
     layout->addLayout(btnLayout, 0);
 
+    QFont tableFont = table->font();
+    tableFont.setPointSize(20);
+    table->setFont(tableFont);
+
     refreshList();
 }
 
@@ -66,20 +71,19 @@ void AdvSettingsDlg::refreshList()
 void AdvSettingsDlg::setDefaults()
 {
     settings->setValue("lircPort", 8765);
-    settings->setValue("remoteName", "No remote selected");
-    settings->setValue("lircConf", "/etc/lircd.conf");
-    settings->setValue("cmd0", "VOL+");
-    settings->setValue("cmd1", "VOL-");
-    settings->setValue("cmd2", "P+");
-    settings->setValue("cmd3", "P-");
+    settings->setValue("remoteName", "");
+    settings->setValue("lircConf", "/home/user/.config/irwi/lirc.conf");
+    settings->setValue("cmd0", "VOLUP");
+    settings->setValue("cmd1", "VOLDOWN");
+    settings->setValue("cmd2", "CHUP");
+    settings->setValue("cmd3", "CHDOWN");
     settings->setValue("cmd4", "POWER");
     settings->setValue("cmd5", "MUTE");
-    settings->setValue("remoteUrl",
-        "http://mercury.wipsl.com/irwi/remotes/");
     settings->setValue("bgAlpha", 192);
     settings->setValue("height", 147);
     settings->setValue("width", 250);
     settings->setValue("idleTimeout", 300);
+    settings->setValue("baseUrl", "http://mercury.wipsl.com/irwi/");
 }
 
 void AdvSettingsDlg::showResetQuery()
