@@ -14,7 +14,7 @@ class AdvSettingsDlg : public QDialog
     Q_OBJECT
 
 public:
-    AdvSettingsDlg(QDialog *parent = 0);
+    AdvSettingsDlg(QWidget *parent);
     ~AdvSettingsDlg();
 
 private:
