@@ -1,10 +1,10 @@
-#ifndef MAINWIDGET_H
-#define MAINWIDGET_H
+#ifndef _MAINWIDGET_H_
+#define _MAINWIDGET_H_
 
 #include <QWidget>
-
 #include "irctrl.h"
 
+class IEngine;
 class QGridLayout;
 class QToolButton;
 class QSettings;
@@ -12,6 +12,7 @@ class QSettings;
 class MainWidget : public QWidget
 {
     Q_OBJECT
+
 public:
     MainWidget (QWidget *parent = NULL);
     ~MainWidget();
@@ -19,16 +20,27 @@ public:
 public slots:
     void showSettingsDialog();
 
+private slots:
+    void sendCmdVolUp();
+    void sendCmdVolDown();
+    void sendCmdChUp();
+    void sendCmdChDown();
+    void sendCmdPower();
+    void sendCmdMute();
+
 protected:
     void paintEvent(QPaintEvent *event);
 
 private:
     void resize();
+
+private:
+    IrCtrl irCtrl;
+
+    QSettings *settings;
     static const int BUTTON_COUNT = 6;
     QGridLayout *layout;
     QToolButton *buttons[BUTTON_COUNT];
-    IrCtrl irCtrl;
-    QSettings *settings;
 };
 
 #endif
