@@ -5,6 +5,9 @@
 #include <QString>
 #include <QMap>
 
+#include "remotedb.h"
+#include "remotedbmgr.h"
+
 class QHBoxLayout;
 class QListWidget;
 class QListWidgetItem;
@@ -18,38 +21,32 @@ class QLabel;
 class SelectRemoteDlg : public QDialog
 {
     Q_OBJECT
+
 public:
-    SelectRemoteDlg(QWidget *parent = 0);
+    SelectRemoteDlg(QWidget *parent);
     ~SelectRemoteDlg();
 
-signals:
-    void remoteDownloaded();
-
 private slots:
-    void alphabetItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
-    
+    void alphabetItemChanged(QListWidgetItem *current,
+                             QListWidgetItem *previous);
     void mfgItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
-    void mfgListDownloadFinished(QNetworkReply *reply);
-
-    void modelListDownloadFinished(QNetworkReply *reply);
-
     void downloadRemote();
-    void remoteDownloadFinished(QNetworkReply *reply);
+    void setDB(RemoteDB *db);
+
+signals:
+    void remoteChanged(Remote);
 
 private:
+    RemoteDBMgr remoteDBMgr;
+
+    QLabel *remoteNameLabel;
     QHBoxLayout *layout;
     QListWidget *alphabetList;
     QListWidget *mfgList;
     QListWidget *modelList;
-    QSettings *settings;
-    QNetworkAccessManager *mfgNetAM;
-    QNetworkAccessManager *modelNetAM;
-    QNetworkAccessManager *remoteNetAM;
-    QMap<QString, QString> *deviceNameMap;
     QPushButton *downloadBtn;
-    QLabel *remoteNameLabel;
+    RemoteDB *remoteDB;
 
-    void beginDownload(const QString &url, QNetworkAccessManager *nam);
     void setBusy(bool busy = true);
 };
 
